@@ -1,7 +1,9 @@
 #!/bin/sh
+# SPDX-License-Identifier: AGPL-3.0-only
+# Copyright 2022 Sxmo Contributors
 
-# shellcheck source=scripts/core/sxmo_icons.sh
-. "$(dirname "$0")/sxmo_icons.sh"
+# shellcheck source=configs/default_hooks/sxmo_hook_icons.sh
+. sxmo_hook_icons.sh
 # shellcheck source=scripts/core/sxmo_common.sh
 . "$(dirname "$0")/sxmo_common.sh"
 
@@ -13,9 +15,9 @@ VVMCONFIG="$VVM_BASE_DIR/vvm"
 defaultconfig() {
 	cat <<EOF
 [Modem Manager]
-"Enable VVM": true
-"VVM Type": cvvm
-"Destination Number": 127
+VVMEnabled=true
+VVMType=cvvm
+VVMDestinationNumber=127
 EOF
 }
 
@@ -56,17 +58,23 @@ editfile() {
 
 newfile() {
 	tmp="$(mktemp)"
-	defaultfile > "$tmp"
+	defaultconfig > "$tmp"
 	editfile "$tmp"
-	mv "$tmp" "$MMSCONFIG"
+	mv "$tmp" "$VVMCONFIG"
 }
 
 mkdir -p "$VVM_BASE_DIR"
 
-systemctl --user stop vvmd.service
+if command -v systemctl > /dev/null; then
+	SERVICE="systemctl --user"
+else
+	SERVICE=superctl
+fi
+
+$SERVICE stop vvmd
 
 finish() {
-	systemctl --user start vvmd.service
+	$SERVICE start vvmd
 }
 trap 'finish' EXIT
 
