@@ -1,30 +1,35 @@
 #!/bin/sh
-
-# shellcheck source=scripts/core/sxmo_common.sh
-. /etc/profile.d/sxmo_init.sh
+# SPDX-License-Identifier: AGPL-3.0-only
+# Copyright 2022 Sxmo Contributors
 
 envvars() {
 	export SXMO_WM=sway
 	export MOZ_ENABLE_WAYLAND=1
 	export SDL_VIDEODRIVER=wayland
+	export XDG_CURRENT_DESKTOP=sway
 	# shellcheck disable=SC2086
 	command -v $TERMCMD "" >/dev/null || export TERMCMD="foot"
 	command -v "$KEYBOARD" >/dev/null || export KEYBOARD=wvkbd-mobintl
 	[ -z "$MOZ_USE_XINPUT2" ] && export MOZ_USE_XINPUT2=1
-	[ -z "$XDG_PICTURES_DIR" ] && export XDG_PICTURES_DIR=~/Pictures
 }
 
 defaults() {
-	alsactl --file /usr/share/sxmo/alsa/default_alsa_sound.conf restore
 	[ -e "$HOME"/.Xresources ] && xrdb -merge "$HOME"/.Xresources
 }
 
+with_dbus() {
+	echo "$DBUS_SESSION_BUS_ADDRESS" > "$XDG_RUNTIME_DIR"/dbus.bus
+	exec /usr/bin/sway -c "$XDG_CONFIG_HOME/sxmo/sway"
+}
+
 start() {
-	# shellcheck disable=SC2016
-	 sh -c '
-		echo "$DBUS_SESSION_BUS_ADDRESS" > "$XDG_RUNTIME_DIR"/dbus.bus
-		/usr/bin/sway -c "$XDG_CONFIG_HOME/sxmo/sway"
-	'
+	if [ -z "$DBUS_SESSION_BUS_ADDRESS" ]; then
+		dbus-run-session -- "$0" "with_dbus"
+	else
+		# with_dbus calls exec because dbus-run-session starts it in a
+		# new shell, but we need to keep this shell; start a subshell
+		( with_dbus )
+	fi
 }
 
 cleanup() {
@@ -34,6 +39,9 @@ cleanup() {
 }
 
 init() {
+	# shellcheck source=scripts/core/sxmo_common.sh
+	. /etc/profile.d/sxmo_init.sh
+
 	_sxmo_load_environments
 	_sxmo_prepare_dirs
 	envvars
@@ -46,7 +54,7 @@ init() {
 
 	start
 	cleanup
-	sxmo_hooks.sh stop
+	sxmo_hook_stop.sh
 }
 
 if [ -z "$1" ]; then
